@@ -39,9 +39,20 @@ def pop_path(environ=None, req=None):
     path = path.split('/')[1:]
 
     if len(path) > 0:
+        script_name = environ.get('SCRIPT_NAME', '/')
+        if not script_name.endswith('/'):
+            script_name += '/'
+        script_name += path[0] + '/'
+
+        environ['SCRIPT_NAME'] = script_name
         environ['PATH_INFO'] = '/' + '/'.join(path[1:])
-        if req is not None and hasattr(req, 'path'):
-            del req.path
+        if req is not None:
+            if hasattr(req, 'path'):
+                del req.path
+            if hasattr(req, 'url'):
+                del req.url
+            if hasattr(req, 'url_root'):
+                del req.url_root
         return path[0]
     return None
 
