@@ -9,9 +9,13 @@ from repoze.who import (middleware as whomiddleware,
 from repoze.who.plugins import basicauth, sql
 from werkzeug import routing
 import jinja2
-from docutils import examples as rstexamples
+from docutils import core as docutilscore
 
-from clue.relmgr import utils, pypi, __version__
+from clue.relmgr import utils, pypi
+
+import pkg_resources
+
+__version__ = pkg_resources.get_distribution('ClueReleaseManager').version
 
 
 template_loader = jinja2.Environment(
@@ -182,7 +186,6 @@ class SimpleIndexApp(AbstractPyPiApp):
             if not try_to_update(self.pypi, distro_id, self.backup_pypis):
                 raise NoSuchDistroError(distro_id)
 
-        files = []
         for fname in self.pypi.get_files(distro_id):
             base = os.path.basename(fname)
             url = '../../d/'+distro_id+'/f/'+base
@@ -245,7 +248,9 @@ class PyPiInnerApp(AbstractPyPiApp):
     urlmap.add(routing.Rule('/login', endpoint='login'))
     urlmap.add(routing.Rule('/logout', endpoint='logout'))
     urlmap.add(routing.Rule('/simple', redirect_to='simple/'))
+    urlmap.add(routing.Rule('/simple/', endpoint='simple'))
     urlmap.add(RegexRule('/simple/.*', endpoint='simple'))
+    urlmap.add(routing.Rule('/<distro_id>/', endpoint='redirect_distro'))
     urlmap.add(routing.Rule('/d/<distro_id>/', endpoint='distro'))
     urlmap.add(routing.Rule('/d/<distro_id>/f/<filename>', endpoint='file'))
     urlmap.add(routing.Rule('/d/<distro_id>/i/<indexname>',
@@ -257,6 +262,19 @@ class PyPiInnerApp(AbstractPyPiApp):
         self.subapp_simple = SimpleIndexApp(pypi, backup_pypis)
         self.backup_pypis = backup_pypis
 
+    def respond_redirect_distro(self, req, distro_id):
+        url = req.url_root
+        if not url.endswith('/'):
+            url += '/'
+        if 'text/html' not in req.headers.get('Accept', '').split(','):
+            # try to catch setuptools
+            url += 'simple/'
+        else:
+            url += 'd/'
+        url += distro_id + '/'
+        print url
+        raise routing.RequestRedirect(url)
+
     def respond_file(self, req, distro_id, filename):
         res = werkzeug.Response()
         res.content_type = 'application/octet-stream'
@@ -302,8 +320,11 @@ class PyPiInnerApp(AbstractPyPiApp):
     @utils.respond
     def respond_distro(self, req, distro_id=None):
         distro = self.pypi.get_distro(distro_id)
-        if distro is None and self.backup_pypis:
-            if not try_to_update(self.pypi, distro_id, self.backup_pypis):
+        if distro is None:
+            if self.backup_pypis:
+                if not try_to_update(self.pypi, distro_id, self.backup_pypis):
+                    raise NoSuchDistroError(distro_id)
+            else:
                 raise NoSuchDistroError(distro_id)
 
         tmpl = self.templates.get_template('distro.html')
@@ -314,6 +335,8 @@ class PyPiInnerApp(AbstractPyPiApp):
             indexes.append({'indexname': x,
                             'url': 'i/'+x})
 
+        files = self.pypi.get_files(distro_id)
+
         kwargs = self.globs(req.environ,
                             distro=self.pypi.get_distro(distro_id),
                             indexes=indexes,
@@ -322,13 +345,16 @@ class PyPiInnerApp(AbstractPyPiApp):
                                  'url': '%sd/%s/f/%s' % (url_root,
                                                          distro_id,
                                                          os.path.basename(x))}
-                                   for x in self.pypi.get_files(distro_id)],
+                                   for x in files],
                             url_root=url_root,
                             rst=self.rst_format)
         return tmpl.render(version=__version__, **kwargs)
 
     def rst_format(self, s):
-        return '<div class="rst">'+rstexamples.html_body(s)+'</div>'
+        published = docutilscore.publish_parts(
+            s, settings_overrides={'halt_level': 10},
+            writer_name='html')
+        return '<div class="rst">'+published['html_body']+'</div>'
 
     def __call__(self, environ, start_response):
         pypi.active_info.username = environ.get('REMOTE_USER', None)
@@ -363,7 +389,7 @@ class PyPiInnerApp(AbstractPyPiApp):
         except pypi.SecurityError, err:
             res = werkzeug.Response('Forbidden', 403)
             res.response = str(err)
-        except pypi.PyPiError, e:
+        except pypi.PyPiError, err:
             res = werkzeug.Response('Forbidden', 403)
             res.response = str(err)
 
